package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!`````!8``#0```!\P0```````#0`(``,
M`"@`'``;``8````T````-````#0```"``0``@`$```0````$`````P```+0!
M``"T`0``M`$``!,````3````!`````$````!````````````````````K`T`
M`*P-```$`````!````$`````$````!`````0``#H60``Z%D```4`````$```
M`0````!P````<````'```*A,``"H3```!``````0```!````W+T``-S-``#<
MS0``/`(``%`"```&`````!````(```#DO0``Y,T``.3-`````0````$```8`
M```$````!````,@!``#(`0``R`$``&P```!L````!`````0```!3Y71D[`$`
M`.P!``#L`0``*````"@````$````!````%#E=&2PL```L+```+"P```<`0``
M'`$```0````$````4>5T9```````````````````````````!@```!````!2
MY71DW+T``-S-``#<S0``)`(``"0"```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`/VF[_Y*)X(OHR:PN\I$Y\,$%*-E!```
M`!@````%````1TY5``$``<`$````"0````(``<`$`````0````0````0````
M`0```$=.50```````P````(``````````@```$4````!````!0`````@`"``
M````10```*U+X\``````````````````````R0(`````````````$@```"4"
M`````````````!(````0`@`````````````2````<0``````````````$@``
M`'L``````````````!(```"*`0`````````````2````RP$`````````````
M$@```%D"`````````````!(```"'```````````````2`````0``````````
M````(````#4"`````````````!(```">`@`````````````2````[`(`````
M````````$@```+D``````````````!(```!A```````````````2````YP``
M````````````$@````,"`````````````!(```#2`0`````````````2````
M_@$`````````````$@```!```````````````"````#<```````````````2
M````=@``````````````$@```+0"`````````````!(````L````````````
M```@````:`(`````````````$@```!8"`````````````!(```"E`@``````
M```````2````4P``````````````$@```"<!`````````````!8````$`0``
M```````````2````:@$`````````````$@```*@``````````````!(```#U
M```````````````2````L0$`````````````$@```($"`````````````!$`
M``"[`@`````````````2````\0$`````````````$@```-H!````````````
M`!(```#H`0`````````````2````S0``````````````$@```*T"````````
M`````!(```#D`@`````````````1````P@$`````````````$@```)H`````
M`````````!(````@`0`````````````2````7@$`````````````$@```/X"
M`````````````!(```#X`0`````````````2````X0$`````````````$@``
M`&<"`````````````!(````L`@`````````````2````.@$`````````````
M$@```!0!`````````````!(````]`@`````````````2````X@(`````````
M````$0```(@"`````````````!(```#:`@`````````````2````1@``````
M````````$0```$\!`````````````!$```#"```````````````2````2P(`
M````````````$@```'L!`````````````!(```"[`0`````````````2````
M;P(`````````````$@```*D!`````````````!(```#"`@`````````````2
M````CP(`````````````(@```*0!`````````````!(```"5`0``!'````0`
M```1`!$``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F54
M86)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!0
M97)L7W-Y<U]T97)M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V9R964`4&5R;%]G
M971?<W8`4&5R;%]A=&9O<FM?=6YL;V-K`'!E<FQ?9&5S=')U8W0`4&5R;%]N
M97=84U]F;&%G<P!P97)L7W)U;@!097)L7VYE=UA3`%!E<FQ?<W9?<V5T<'9N
M`'!E<FQ?86QL;V,`4&5R;%]S=E]S971P=@!P97)L7V-O;G-T<G5C=`!B;V]T
M7T1Y;F%,;V%D97(`4&5R;%]S869E<WES;6%L;&]C`%!,7V-U<G)E;G1?8V]N
M=&5X=`!097)L7V-R;V%K7VYO8V]N=&5X=`!03%]M96UO<GE?=W)A<`!097)L
M7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K`%!E<FQ?<WES7VEN:70S`'!E<FQ?
M<&%R<V4`7TE/7W-T9&EN7W5S960`97AI=`!L<V5E:S8T`')E861D:7(V-`!S
M=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`'-T<G1O:P!G
M971P=W5I9`!S=')L96X`<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`;6MD:7(`
M7U]V9G!R:6YT9E]C:&L`9V5T<&ED`')E861L:6YK`')E86QL;V,`7U]S<')I
M;G1F7V-H:P!?7VUE;6UO=F5?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?
M7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE
M`'-T<F-H<@!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?
M7V5R<FYO7VQO8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?
M871F;W)K`%]?<W1A8VM?8VAK7V9A:6P`;&EB<&5R;"YS;RXU+C0P`&QI8F,N
M<V\N-@!'3$E"0U\R+C$N,P!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R
M+C(`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"0U\R+C,N-`!'3$E"0U\R
M+C$`1TQ)0D-?,BXP``````(``@`"``$``0`!``,`!``!``$``@`"``4``0`!
M``$`!``"``(``0`!``(``@`!``8`!``"``$``0`!``$``0`!``<``@`"``(`
M`@`"``$``@`"``(``0`"``$`"``"``(`!@`"``$``0`$``(``@`"``$``0`!
M``0``0`"``D``P`"``H``@`!``$`"0`?`P``$`````````!S'VD)```*`"D#
M```0````M)&6!@``"0`U`P``$````!1I:0T```@`0`,``!`````2:6D-```'
M`$H#```0````LY&6!@``!@!4`P``$````'(9:0D```4`7P,``!````!T&6D)
M```$`&L#```0````$6EI#0```P!W`P``$````!!I:0T```(`@0,```````#<
MS0``"````.#-```(````_,\```@````$T```"````!30```(````S,\```8)
M``#0SP``!@H``-3/```&%```V,\```88``#<SP``#AT``.#/```&'@``Y,\`
M``8?``#HSP``!B,``.S/```&*@``\,\```8Z``#TSP``!CL``/C/```&0P``
M\,X```<!``#TS@``!P(``/C.```'`P``_,X```<$````SP``!P4```3/```'
M!@``",\```<'```,SP``!P@``!#/```'"P``%,\```<,```8SP``!PT``!S/
M```'#@``(,\```</```DSP``!Q```"C/```'$0``+,\```<2```PSP``!Q,`
M`#3/```'%0``.,\```<6```\SP``!Q<``$#/```'&0``1,\```<:``!(SP``
M!QL``$S/```''```4,\```<@``!4SP``!R$``%C/```'(@``7,\```<D``!@
MSP``!R4``&3/```')@``:,\```<G``!LSP``!R@``'#/```'*0``=,\```<K
M``!XSP``!RP``'S/```'+0``@,\```<N``"$SP``!R\``(C/```',```C,\`
M``<Q``"0SP``!S(``)3/```',P``F,\```<T``"<SP``!S4``*#/```'-@``
MI,\```<X``"HSP``!SD``*S/```'/```L,\```<]``"TSP``!SX``+C/```'
M/P``O,\```=```#`SP``!T$``,3/```'0@``R,\```=$````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%.#[`CH)P8``('#V[X``(N#[````(7`=`+_T(/$"%O#_[,$````_Z,(````
M`````/^C#````&@`````Z>#_____HQ````!H"````.G0_____Z,4````:!``
M``#IP/____^C&````&@8````Z;#_____HQP```!H(````.F@_____Z,@````
M:"@```#ID/____^C)````&@P````Z8#_____HR@```!H.````.EP_____Z,L
M````:$````#I8/____^C,````&A(````Z5#_____HS0```!H4````.E`____
M_Z,X````:%@```#I,/____^C/````&A@````Z2#_____HT````!H:````.D0
M_____Z-$````:'````#I`/____^C2````&AX````Z?#^____HTP```!H@```
M`.G@_O___Z-0````:(@```#IT/[___^C5````&B0````Z<#^____HU@```!H
MF````.FP_O___Z-<````:*````#IH/[___^C8````&BH````Z9#^____HV0`
M``!HL````.F`_O___Z-H````:+@```#I</[___^C;````&C`````Z6#^____
MHW````!HR````.E0_O___Z-T````:-````#I0/[___^C>````&C8````Z3#^
M____HWP```!HX````.D@_O___Z.`````:.@```#I$/[___^CA````&CP````
MZ0#^____HX@```!H^````.GP_?___Z.,````:``!``#IX/W___^CD````&@(
M`0``Z=#]____HY0```!H$`$``.G`_?___Z.8````:!@!``#IL/W___^CG```
M`&@@`0``Z:#]____HZ````!H*`$``.F0_?___Z.D````:#`!``#I@/W___^C
MJ````&@X`0``Z7#]____HZP```!H0`$``.E@_?___Z.P````:$@!``#I4/W_
M__^CM````&A0`0``Z4#]____H[@```!H6`$``.DP_?___Z.\````:&`!``#I
M(/W___^CP````&AH`0``Z1#]____H\0```!H<`$``.D`_?___Z/(````:'@!
M``#I\/S___^CS````&B``0``Z>#\____H]````!HB`$``.G0_/___Z/4````
M:)`!``#IP/S___^CV````&B8`0``Z;#\____H]P```!HH`$``.F@_/___Z/@
M````:*@!``#ID/S___^CY````&BP`0``Z8#\____HQ0!``!FD```````````
M`````````````````````/,/'ON-3"0$@^3P_W'\58GE5XG/5E/H50(``('#
M";L``%&#["R+002)1=2+00B)1=!EH10```")1>2-1=!0C4744%'H./___XN#
MZ````(/$#%!0_[,``0``Z')5``"+@PP!``"#Q!"`.``/A!T!``"+@_@```!E
MBP"`B+H"```#BP>-<`.#P`2)=<P]____/P^'>0$``(/L#,'@`E#H?O[__XMU
MU(L_@\00B<&)@T`!``"+!HD!C8,'H___B4$$BX,P`0``B4$(C8,*H___B4$,
M@_\!#XY)`0``B4W(C48$C5$0C32^+HVT)@````!FD(L(@\`$@\($B4K\.<9U
M\8M-R(/'`X/L#(V#?$[__\<$N0````!J`%'_=<Q0_[-$`0``Z)G[__^#Q""%
MP`^$CP```(/L#/^S1`$``(U]X.A-_?__B?J)QHV#PZ'__^@N`@``@\00A<!T
M?H/L#/^S1`$``.@Y^___Z'3\__^#Q!"+1>1E*P44````#X6X````C67PB?!9
M6UY?78UA_,/H[OO__XF#1`$``(7`#X2-````@^P,4.A7_/__BX/X````@\00
M98L0QH)>!0```.FU_O__@^P,_[-$`0``Z%'[__^#Q!#I6____XN#/`$``(7`
M=!&#[`Q0Z/8>``"#Q!#I9____XGZC8-XH?__Z($!``")@SP!``"%P`^$3/__
M_^O24%"-@W.A____LQ`!``!0Z.W\__^_!````.G8_O__@^P,:@'HF?W__^C$
M4P``9I!FD#'M7HGA@^3P4%12Z!@```"!P]2X``!J`&H`45;_LQ@!``#H.?W_
M__2+'"3#9I!FD(L<),-FD&:09I!FD&:09I#HY````('"G[@``(V*-`$``(V"
M-`$``#G(=!V+@O````"%P'0358GE@^P44?_0@\00R<,NC70F`,.-M"8`````
MZ*0```"!PE^X``!5B>53C8HT`0``C8(T`0``@^P$*<B)P\'H'\'[`@'8T?AT
M%(N2]````(72=`J#[`A04?_2@\00BUW\R<,NC;0F`````)#S#Q[[58GE4^A3
M____@<,'N```@^P$@+LT`0```'4GBX,4`0``A<!T$8/L#/^S(`$``.B9_/__
M@\00Z#'____&@S0!```!BUW\R<,NC70F`/,/'OOI5____XL4),-FD&:09I!F
MD&:09I!FD&:09I"058G!5U93Z.7^__^!PYFW``"#[!R)5"0(BX,(`0``BQ"%
MT@^$FP````^V`83`=`0\/755,>V+,H7V=#R)5"0,B?")UHE,)`2)QXVT)@``
M``"#[`15_W0D#%?H<OO__X/$$(7`=0:`/"\]=#6+?@2#Q@2%_W7;B?Z#Q!R)
M\%M>7UW#C;0F`````(G-#[9%`8/%`83`=`0\/77Q*<WKF(UV`(M4)`R)^(GW
MB<:+1"0(*=>-="X!P?\"B3B#Q!R)\%M>7UW#,?;KL"Z-M"8`````D%93Z!G^
M__^!P\VV``"#['QEBS44````B70D=(G&C40D%%!6Z'CZ__^#Q!"%P'4YBU0D
M'('B`/```('Z`$```'0(@?H`H```=2&#[`AJ`E;H_/C__X/$$(7`#Y3`#[;`
MZPF-M"8`````,<"+5"1L92L5%````'4&@\1T6U[#Z"Y1```NC;0F`````(VV
M`````%575E/HA_W__X'#.[8``('LC````&6+-10```")="1\B<:%]G0%@#X`
M=26+1"1\92L%%`````^%30$``('$C````%M>7UW#+HVT)@````"0@^P,5NB7
M^/__@\00B<>%P'3)@^P,5^C%^/__@\00A<`/A,H```"`>!,NC5`3=1&`>@$`
M=-TNC;0F`````(UV`(!X$RX/A,8```")5"0(@^P,5NBI^/__BU0D&(G%B10D
MB50D'.B7^/__C4P%`HD,)(E,)!CH]_C__XG%6(V#)*'__UJ+5"044E90BTPD
M'%%J`E7H:?G__X/$&(U$)"105>C;]___@\00@_C_=!"+1"0L)0#P```]`$``
M`'1S@^P,5>A*^/__@\00@^P,5>B.]___@\00@^P,5^@"^/__@\00A<`/A3W_
M__^-M"8`````@^P,5^A7^/__B30DZ)_X__^#Q!#ITO[__XVT)@````"`>@$N
M#X4P____@'H"``^$[O[__^DA____C;0F`````(GHZ'G^___KD.B23P``9I!5
MB<4QP%=64^CS^___@<.GM```@^Q(@#H]98LU%````(ET)#B)U@^4P`'&5NB/
M]___@\00B40D$(U4)"B)Z.C-_/__A<`/A!4!``"#[`R)QU#H:O?__XM,)""#
MQ!`YR`^#VP```(M$)"C!X`*)1"04BX,(`0``B40D#`^V10"$P`^$L@$``#P]
M#X2J`0``B>@/ME`!@\`!A-)T!8#Z/77P*>B+3"0,BWPD%(/L#(M4)!P#.8U$
M$`)0Z'/W__^#Q!")!X7`=%F+3"0,BWPD%(L!C4T!BQ0X#[9%`(@"/#UT(X3`
M=1#K'2Z-M"8`````9I`\/70/#[8!@\(!@\$!B`*$P'7MQ@(],<`NC;0F````
M``^V#`:(3`(!@\`!A,EU\8M$)"QE*P44````#X4>`0``@\0\6UY?7<,NC;0F
M`````#'`+HVT)@````"-M@`````/MA0&B!0'@\`!A-)U\NN_BX,(`0``BQ")
M1"0,BSJ%_P^$R0```#'_+HVT)@````")^(/'`8L,NH7)=?2-!(4,````B40D
M&(N#.`$``(7`=6>)5"0<@^P,_W0D),>#.`$```$```#H=?;__X/$$(G!A<`/
MA%?___^-!+T`````B40D%/]T)!A0BU0D)%)1B4PD*.@9]___BT0D'(M,)"B#
MQ!")",=$N00`````B7PD*.EU_O__C78`@^P(_W0D(%+H:_3__XG!BT0D'(/$
M$(D(A<D/A/?^__^-!+T`````B40D%.N_C78`,<#I8_[__\=$)!@(````,?_I
M2?___^@]30``+HVT)@`````NC70F`%575E.![``0``"##"0`@^PPZ(KY__^!
MPSZR``!EBST4````B;PD(!```(G7:/\/``")QHV#*J'__XUL)"154.CL]?__
M@\00A<!^$(G"C4#_@'P4&P!U.87`=3&+@_@```"#[`175F7_,.@"]/__@\00
MBX0D'!```&4K!10```!U0('$+!```%M>7UW#B<)FD(/L!%*)5"04:B]5Z-#U
M__^#Q!"%P'2TBU0D#(N#^````%)55F7_,.C4]/__@\00Z[#H:DP``"Z-M"8`
M````9I#S#Q[[5E/HQ?C__X'#>;$``(/L!(V#@.'__XNS^````%"-@SFA____
ML_P```!09?\VZ(KU__]8C8/DHO__6FH`4%"-@[QC__]0C8-5H?__4&7_-NCX
M\___@\0D6U[#9I#S#Q[[4^AF^/__@<,:L0``@^P(C8.`X?__4(V#.:'___^S
M_````%"+@_@```!E_S#H*_7__X/$&%O#C;8`````\P\>^U575E.![``0``"#
M#"0`@>P`$```@PPD`(/L+#'MZ`KX__^!P[ZP``!EH10```")A"0<(```,<#H
M`/+__X/L"(V3-:'__U)0C8-JH?__4&@!$```:@*-="0V5NB-]/__@\0<:``0
M``"-O"0C$```5U;H1_3__X/$$(7`>#"#[`R-4`&)QE*)5"0<Z,[S__^#Q!")
MQ87`=!6+5"0,4E974.AH\O__QD0U``"#Q!"+A"0<(```92L%%````'4-@<0L
M(```B>A;7E]=P^CN2@``+HVT)@````"-M@````#S#Q[[Z1?___^-M"8`````
M\P\>^U575E.![``0``"##"0`@>R<````Z"/W__^!P]>O``"+O"2P$```98LM
M%````(FL)(P0``"+K"2T$```C40D+(E$)!2)PHV#>*'__^C\]___@^P(:B^)
MQE?H;_'__X/$$(7`=#B-@X&A__^)^NC+^O__B?B+E"2,$```92L5%`````^%
MI0$``('$G!```%M>7UW#+HVT)@````!FD(/L#%7HM_/__UI9C8N.H?__B4PD
M%%%0Z/3R__^#Q!"-BY"A__^)Q8V#F:+__XE$)!B%[723@'T``(E,)!P/A/<`
M```NC;0F`````"Z-="8`A?9T%8/L"%56Z)+S__^#Q!"%P`^$K````(/L#%7H
M[O'__X/$$(G"C40%_SG%<AOK+"Z-M"8`````C;0F`````,8``(/H`3G%=`6`
M."]T\8/L#%7HN/'__X/$$(G"B50D$(/L#%?HIO'__XM4)""#Q!"-1`(!/?\/
M```/A_C^__^#[`17_W0D)%7_="0H:``0``!J`HVL)*@```!5Z&_R__^#Q!C_
M="0<5>CB\/__@\00A<!U$(M$)#PE`/```#T`@```=$N#[`C_="04:@#H[?'_
M_X/$$(G%A<`/A)C^__^`?0``#X46____A?9T!8`^+G05N@$```"-JW:A___I
M6O___RZ-="8`@'X!`'2WZ^.#[`AJ`57H9?#__X/$$(7`=:.)ZHV#@:'__^@A
M^?__@^P,5>@X\O__@\00Z4?^___HFT@``"Z-M"8`````C78`\P\>^U93Z/7T
M__^!PZFM``"#[`R+="08:B]6Z-#O__^%P(U0`0]%\HDT).CP\?__@\046U[#
M+HVT)@````!FD/,/'OM55U93@>P`$```@PPD`(/L'.BF]/__@<-:K0``98LU
M%````(FT)`P0``"+M"0P$```A?8/A),```"`/@`/A(H```"#[`Q6Z#'P__^#
MQ!"-2`&)PC'`@?D`$```=U.-;"0,@_D$<WZ%R0^%C@```(U$%?\YQ7(0ZQ.-
M="8`Q@``@^@!.>AT!8`X+W3Q@^P(:B]5Z!;O__^#Q!"%P'0O.<5S`\8``(/L
M#%7H+_'__X/$$(N4)`P0``!E*Q44````=5N!Q!P0``!;7E]=PY"#[`R-@W:A
M__]0Z`'Q__^#Q!#KT(UT)@"+1`[\B>^)1`P(B='!Z0+SI>ET____9I`/M@:(
M1"0,]L$"#X1B____#[=$#OYFB40,"NE3____Z"Q'```NC;0F`````(UT)@#S
M#Q[[55=6Z,42``"!QCBL``!3@^PL98L=%````(E<)!R-7"08BZX(`0``C;Z2
MH?__B=J)^.AF]/__A<!T.XM4)!B+10"-!)"+4`2)$(72=.`NC;0F`````(VT
M)@````"+4`B#P`2)$(72=?2)VHGXZ"OT__^%P'7%BZX(`0``C;Z;H?__B=J)
M^.@2]/__A<!T-XM4)!B+10"-!)"+4`2)$(72=.`NC;0F`````(UV`(M0"(/`
M!(D0A=)U](G:B?CHV_/__X7`=<F+K@@!``"-OJ.A__^)VHGXZ,+S__^%P'0W
MBU0D&(M%`(T$D(M0!(D0A=)TX"Z-M"8`````C78`BU`(@\`$B1"%TG7TB=J)
M^.B+\___A<!UR8NN"`$``(V^K*'__XG:B?CH<O/__X7`=#>+5"08BT4`C020
MBU`$B1"%TG3@+HVT)@````"-=@"+4`B#P`2)$(72=?2)VHGXZ#OS__^%P'7)
MC8:SH?__B[X(`0``B00DBP0DB=KH'O/__X7`=#2+5"08BP>-!)"+4`2)$(72
M=.`NC;0F`````(M0"(/`!(D0A=)U](L$)(G:Z.KR__^%P'7,BZX(`0``C;[#
MH?__B=J)^.C1\O__A<!T-HM4)!B+10"-!)"+4`2)$(72=.`NC;0F`````&:0
MBU`(@\`$B1"%TG7TB=J)^.B;\O__A<!URHV&>*'__XN^"`$``(E$)`2+1"0$
MB=KH?/+__X7`=#.+5"08BP>-!)"+4`2)$(72=-^-M@````"+4`B#P`2)$(72
M=?2+1"0$B=KH2?+__X7`=<V-AL^A__^+O@@!``")1"0,BT0D#(G:Z"KR__^%
MP'0QBU0D&(L'C020BU`$B1"%TG3?C70F`(M0"(/`!(D0A=)U](M$)`R)VNCY
M\?__A<!USXV&V:'__XN^"`$``(E$)`B+1"0(B=KHVO'__X7`=#&+5"08BP>-
M!)"+4`2)$(72=-^-="8`BU`(@\`$B1"%TG7TBT0D"(G:Z*GQ__^%P'7/BZX(
M`0``C;[CH?__B=J)^.B0\?__A<!T-8M4)!B+10"-!)"+4`2)$(72=.`NC;0F
M`````)"+4`B#P`2)$(72=?2)VHGXZ%OQ__^%P'7+BZX(`0``C;Z!H?__B=J)
M^.A"\?__A<!T-XM4)!B+10"-!)"+4`2)$(72=.`NC;0F`````(UV`(M0"(/`
M!(D0A=)U](G:B?CH"_'__X7`=<F)VHV&[:'__^CZ\/__A<!T"XG"BT0D".C;
M\___B=J-AOZA___HWO#__X7`=`V)PHV&$*+__^B]\___B=J-AANB___HP/#_
M_XG"A<!T*XM$)`3HH?/__XM$)!QE*P44````=3.+!"2#Q"R-ECRB__];7E]=
MZ7_S__^)VHV&*Z+__^B"\/__A<!TS8G"BT0D#.AC\___Z\#H[$(``"Z-M"8`
M````C70F`/,/'OOHA`X```7[IP``@^P<98L5%````(E4)`R-5"0(C8#/H?__
MZ#7P__^%P'0Q#[80@/HP#Y3`A-(/E,()T(/P`0^VP(M4)`QE*Q44````=1*#
MQ!S#+HVT)@````!FD#'`Z^'H=T(``(VT)@````#S#Q[[4^C6[O__@<.*IP``
M@^P(C40D%%#_="04BX,$`0``:@+_,.@%ZO__QP0D_P```.@)[/__+HVT)@``
M``"055=64XV<)```__^![``0``"##"0`.=QU\H/L+.A_[O__@<,SIP``98LM
M%````(FL)!P``0")Q6H":@!J`%7HG>O__X/`_X/2_XE$)!B+="08B=>)5"0<
MP?\?,?@I^#'2)?__```Q^C'X*?@9^HM\)!PIQHET)!@9UXE\)!R#Q!"-="04
MA?\/B,P```"-="8`:@#_="00_W0D$%7H0.O__X/$$"'0@_C_#X3"````@^P$
M:`@``0!65>CCZ/__@\00@_C_#X28````@_@'=F*-1`;X.?!R6HT])`$``.L9
M+HVT)@`````NC;0F`````&:0@^@!.?!R.8L0BT@$,Q0?,TP?!`G*=>DI\)D#
M1"0($U0D#(N,)!P``0!E*PT4````=5V!Q"P``0!;7E]=PXUV`(%$)`@``/__
MBU0D"(-4)`S_BTPD#(G0B<HU``#___?2"=`/A3C___^X_____XG"Z[&#[`R-
M@TNB__]0Z%#^__^#[`R-@SZB__]0Z$'^___HK$```"Z-M"8`````C70F`/,/
M'OM3Z`;M__^!P[JE``"#[`CH^.C__X/L#%#HS^C__X/$$(7`=`*+`(/$"%O#
MD/,/'OM55U93Z-/L__^!PX>E``"#["QEBRT4````B6PD'(ML)$"-5"08C;M7
MHO__B?CHNNW__X7`=`>`.`")QG4?BT0D'&4K!10```!U=8GJ@\0LB?A;7E]=
MZ8+P__]FD(/L#%7H-^C__XDT)(E$)!SH*^C__XM4)!R-3`("B0PDB4PD'.B'
MZ/__@\0,B<*-@XZA__]64(V#F:+__U50BTPD(%%J`E*)5"0LZ/'H__^#Q""+
M5"0,BT0D'&4K!10```!TC>BH/P``+HVT)@````#S#Q[[C4PD!(/D\/]Q_%6)
MY5?H/@L``(''K:0``%9348'L"`$``(L!C8]NHO__B84`____9@]NP8V/)J+_
M_V8/;LF-CPFB__]EH10```")1>2-AW:A___'18``````QT6L`````,=%D```
M``!F#V[0C8=[HO__9@]BPF8/;MB-AW.B__]F#V[@9@_6A7C___]F#V[!9@]B
MRV8/8L2-AX2B__^-CW^B__]F#VS!9@]NZ(V%&/___P\119QF#V[!B<*)A13_
M__]F#V+%C8=XH?__B87T_O__9@_618CH0.S__X7`=`F`.``/A<,%``")^^@<
MY___@^P,4.CSYO__@\00A<`/A.@$``"+`(F%$/___X7`#X38!```@^P,4.BO
MYO__@\00B?N-=``!@^P,5N@-Y___@\00B?&)PHN%$/___XF5^/[__P^V`(3`
M#X1\````C9^-HO__B8T$____B?&+M1#___^)G0C___\NC70F`(/L#`^VP(G[
M@\8!4/^U"/___U&)C0S___]J`E*)E1#____H.>?__XN-#/___XN%!/___XN5
M$/___SG!#T/!B<,IR(/``CG8#T+#*=F#P@*#Q""-3`'^#[8&A,!UHXU=F(V'
M$*+__^L2+HVT)@````"+0P2#PP2%P'0VBY44____Z"OK__^)QH7`=.6`.`!T
MX.CKZ___A<!TUX/L#(G[5N@<Y___@\00B<:%P'4]C78`C95X____BS*%]G0N
M@#X`#X2K`P``B?")E1#____HKNO__XN5$/___X7`#X4H`0``BW($@\($A?9U
MTH/L#(G[5NAKY?__6HF%$/____^U^/[__^A9Y?__BY40____C80"!`0``(F%
M#/___XD$).BNY?__C9>0H?__B84(____B<&-AY*B____M?C^__]0C8>7HO__
MB94$____4E:)SE#_M0S___]J`E'H!.;__X/$*&C``0``5NA6X___@\00@_C_
M=1#H*>/__XL`@_@1#X6.`P``@^P(_[44____B?O_M0C____HB.7__X/$$(G&
MA<`/A),```"#[`S_M0C___^+A0#___^)^_\PC8=,H___4(N'!`$``&H"_S#H
M0N/__X/$(,>%$/___P`````NC70F`(M%Y&4K!10````/A0P%``"+A1#___^-
M9?!96UY?78UA_,.-M@````"#[`R)E1#___^)^U;HI^7__XN5$/___X/$$(G&
M@\($A<`/A(?^___IMO[__XUT)@"+A2C___\E`/```#T`0```#X57____BX4P
M____B840____Z$'D__\YA1#___\/A3K___^+A2C___\E_P$``#W``0``#X4D
M____@^P,_[4,____Z$'D__^+E13___^)A1#___^-AV*B___H"NG__X/$$(7`
M#X2_`@``@^P(4(N%`/____\PZ)[P__^#Q!")A?C^__^%P`^$G0(``(/L#/^U
M^/[__XG[Z'WC__^#Q!")PH/X`W93@^P(C8>@HO__4(N%^/[__XF5\/[__XU$
M$/Q0Z./D__^#Q!"%P'4LBY7P_O__@_H$#X1T`P``BX7X_O__@'P0^R\/A&,#
M```NC;0F`````(UT)@"+E13___^-A\^A__^)A13____H6>C__X7`#X0I`@``
M#[8`A,`/A!X"```\,`^$%@(``(N%%/___XV7/*+__XG[Z!OK___H)N'__XV/
MY*+__XF-%/___U%0C8?$HO___[4$_____[4(____4/^U#/___VH"_[40____
MZ*+C__^-A]*B__^#Q"")A0#____K2)#HR^#__X,X$75:B?N#Q@'HS.#__X/L
M#/^U%/___U90_[4$_____[4(_____[4`_____[4,____:@+_M1#____H3./_
M_X/$,(/L"(G[:,`!``#_M1#____HE.#__X/$$(/X_W2<@^P,_[4(____B?OH
M?.'__XN]$/___XN%]/[__XGZZ$GJ__^)/"3H8?G__X/$$.EY_?__+HVT)@``
M``"0,?;I<_S__RZ-M"8`````D(UUB"Z-M"8`````+HUT)@"+!H7`=!Z+E13_
M___H#^?__X7`=`6`.`!U1HM&!(/&!(7`=>*#[`R)^[X-````:@WH"^+__X/$
M$+D-````B87X_O__B<*-AV>B__^)A1#___^X4P```.GV^O__+HUT)@"#[`R)
M^X/&!%#HPN+__X/$$(7`=(N)A1#____IF/K__X/L"%#_M0C___^+A0#_____
M,(V'$*/__U"+AP0!``!J`O\PZ-C?__^#Q"#ID?S__X/L#(G[4(F%%/___^AO
M^/__BX44____B00DZ&'B__^#Q!")A1#____I<_S__XUV`(N%`/___XL`B87X
M_O__Z5#]__\NC70F`(/L"(G[:@#_M?C^___H9M___X/$$(7`#X3-_?__B84`
M____Z%#V__^)A?C^__^)E?S^__^%T@^(KOW__X/`]FH`@]+_4E"+C0#___]1
MZ`;B__^#Q`R-1;5J!E"+C0#___]1Z+'?__^#Q!"+C0#___^#^`8/A0`!``"!
M?;4`0T%##X5D_?__9H%]N4A%#X58_?__:@"+A?C^__^-=;N+E?S^__^#P,Z#
MTO]24%&)C13____HH>'__X/$#&HH5HN-%/___U'H3]___X/$$(/X*`^%I```
M`(V'Y*+__\9%XP!0C8>UHO__5O^U!/____^U"/___U#_M0S___]J`O^U$/__
M_^C1X/__@\0@Z9W]__^+A0#___^+2`2%R0^$F/S__X/L#(G[48F-`/___^BG
MW___@\00@_@##X9[_/__@^P(C9>EHO__4HN-`/___XU$`?Q0Z!'A__^#Q!"+
MC0#___^%P`]%C?C^__^)C?C^___I1/S__^@O-P``@^P,C8>JHO__4.BP]/__
M\P\>^U575E/H@^/__X'#-YP``(/L'(U\)`B)^F6+-10```")="0,B[/X````
M98LN#[9%:(A%:8V#LZ'__^A>Y/__A<!T"8`X,0^$20$``.BL[___98LNC8/C
MHO__:@-J`5!5Z.C=__^#Q!")Q87`="F#[`2-@^6B__]0BT4,_S!E_S;HV-W_
M_XM%#(/$$(L`]D`*0`^%+@$``(V#ZJ+__VH#:@%09?\VZ*/=__^#Q!")Q87`
M="J)^HV#@:'__^C=X___BU4,BPJ%P`^$X````(/L!%!19?\VZ(/=__^#Q!"#
M[`2-@^RB__]J`5!E_S;HW-S__X/$#(V3`:/__U)09?\VZ%G=__]EBP:)^L9`
M:0"-@WBA___HA>/__X/$$(F#/`$``(G&A<!T/H/L"&C``0``5NAXW/__@\00
MC5`!@_H!=@F#^!$/A9````"+1"0,92L%%`````^%E0```(/$'%M>7UW#C78`
M@^P,_[-``0``Z`KV__^#Q!")@SP!``")QH7`=:6#[`R-@Z"C__]0Z)S>__^-
M="8`@'@!``^$M?[__^FH_O__+HVT)@````"0BX-``0``BQ")R.@QZ/__Z1S_
M__^-="8`@^P(4&7_-NC\W?__@\00Z;[^__]0BX-``0``5O\PC8/$H___4.@^
MWO__Z"DU```NC;0F`````)#S#Q[[5U93Z(3A__^!PSB:``"#[!!EBS44````
MB70D#(MT)""-5"0(C8//H?__Z&WB__^%P'0;#[80A-(/E,"`^C`/E,((T'4)
MA?9T!8`^`'4>BT0D#&4K!10```!U:8/$$%M>7\,NC;0F`````&:0@^P,5NA7
M[/__B<=86FHO5^C[V___A<"-4`$/1?J)/"3H&][__X/$#(V3DJ+__VH$4E#H
MR=W__X/$$(7`=:2+1"0,92L%%````'4-@\00B?!;7E_I../__^A3-```BP0D
MPXLT),.+/"3#9I!FD&:0D%6)Y5?H[/___X''6YD``%93@^3P@>P0`P``B7PD
M4(G'C90D"`$``(VT)(@```")1"1<9:$4````B80D#`,``(GXB50D8(UX.(V$
M)(````")1"1(+HVT)@`````NC70F`(M/!(L',=(QVXE4)'0QTH/&$(/'"`_(
MB4;HB<@)VL'H"(E,)'C!Z1B)1"1P)0#_```)R(E,)&B+3"1XB5PD;#';P>$8
M"=HQV\=&[``````)R(M,)'@)VL=$)'P`````B5;TP>$(@>$``/\`"<B)1O"+
M1"1@.<9UB(M\)%"+1"1(C90DZ````&8/;X0DD````&8/;Y0DH````&8/;XPD
ML````&8/;Z>,X?__!6@"``"0\P]O*F8/;]EF#V]*V(/"$&8/[T*(9@_OZ68/
M[\5F#V_H9@]S\`%F#W/5'V8/Z\5F#]O$#RE""&8/;\)F#V_3.<)UO8M<)%R+
M4PR+,XM[!(M#"(M+$(E4)$2)VHM;%(E$)$")\(E,)'C!X`6)7"1\B=.+4AB+
M2QR)5"0XBU,@B4PD/(M+)(E4)`B)3"0,B?$/K/D;"<B+3"0(`XPD@````('!
MF7F"6@'(BTPD>#-,)#@C3"1`,TPD.`'(,=*)1"1@BT0D0(E4)&2+5"1$B<&)
MTP^LT`(/I,L>P>$>"<'!Z@()TXE,)&B)RC')B5PD;(E4)%"+1"10B4PD5(M,
M)'B+7"0XB70D2#'(B7PD3(M\)$PA\#'(`YPDB````(G9B<:+7"1D@<&9>8):
M`<Z+3"1@B<@/K-D;B?O!X`4)R`'&,=*)="1PBW0D2(E4)'2)^@^D\Q[!Z@*)
M\8GPP>$>B=X/K/@""=8QTHG+B50D+(M4)&@)PXM$)&")7"0H,=J)7"0PBUPD
M>"'0,T0D4`.<))````")="0TB=F)QHM<)'2!P9EY@EH!SHM,)'")R`^LV1N+
M7"1@P>`%"<B)V@'&,<G!XAZ)="1HBW0D9(G0B4PD;(GQ#Z39'@^L\P+![@*)
MRHG9B?.)QHG7"<XQR0G?B70D((E,)"2+1"0PB70D,(M<)&PQ\(MT)%`C1"1P
MB7PD-#-$)"@#M"28````B?&)QH'!F7F"6@'.BTPD:(G(#ZS9&XM<)'#!X`4)
MR(G:`<8QR<'B'HET)&"+="1TB=")3"1DB?$/I-D>#ZSS`HG*P>X""=B+7"1D
M"?*)1"08B=8QTHE$)%")5"0<BU0D,(ET)%2+="0H,<*+1"1H(=`S1"0@`[0D
MH````(GQB<:!P9EY@EH!SHM,)&")R`^LV1N+7"1HP>`%"<B)V@'&,<G!XAZ)
M="1PBW0D;(G0B4PD=(GQ#Z39'@^L\P+![@*)RHG9B?.)QHG7"<XQR0G?B70D
M,(E,)#2+1"10B70D4(M<)'0Q\(MT)"`C1"1@B7PD5#-$)!@#M"2H````B?&)
MQH'!F7F"6@'.BTPD<(G(#ZS9&XM<)&#!X`4)R(G:`<8QR<'B'HET)&B+="1D
MB=")3"1LB?$/I-D>#ZSS`HG*P>X""=B+7"1L"?*)1"0HB=8QTHE4)"R+5"10
MB40D4#'"BT0D<(ET)%2+="08(=`S1"0P`[0DL````(GQB<:!P9EY@EH!SHM,
M)&B)R`^LV1N+7"1PP>`%"<B)V@'&,<G!XAZ)="1@BW0D=(G0B4PD9(GQ#Z39
M'@^L\P+![@*)RHG9B?.)QHG7"<XQR0G?B70D((E,)"2+1"10B70D4(M<)&0Q
M\(MT)#`C1"1HB7PD5#-$)"@#M"2X````B?&)QH'!F7F"6@'.BTPD8(G(#ZS9
M&XM<)&C!X`4)R(G:`<8QR<'B'HET)'"+="1LB=")3"1TB?$/I-D>#ZSS`HG*
MP>X""=B+7"1T"?*)1"0PB=8QTHE4)#2+5"10B40D4#'"BT0D8(ET)%2+="0H
M(=`S1"0@`[0DP````(GQB<:!P9EY@EH!SHM,)'")R`^LV1N+7"1@P>`%"<B)
MV@'&,<G!XAZ)="1HBW0D9(G0B4PD;(GQ#Z39'@^L\P+![@*)RHG9B?.)QHG7
M"<XQR0G?B70D*(E,)"R+1"10B70D4(M<)&PQ\(MT)"`C1"1PB7PD5#-$)#`#
MM"3(````B?&)QH'!F7F"6@'.BTPD:(G(#ZS9&XM<)'#!X`4)R(G:`<8QR<'B
M'HET)&"+="1TB=")3"1DB?$/I-D>#ZSS`HG*P>X""=B+7"1D"?*)1"0@B=8Q
MTHE4)"2+5"10B40D4#'"BT0D:(ET)%2+="0P(=`S1"0H`[0DT````(GQB<:!
MP9EY@EH!SHM,)&")R`^LV1N+7"1HP>`%"<B)V@'&,<G!XAZ)="1PBW0D;(G0
MB4PD=(GQ#Z39'@^L\P+![@*)RHG9B?.)QHG7"<XQR0G?B70D,(E,)#2+1"10
MB70D4(M<)'0Q\(MT)"@C1"1@B7PD5#-$)"`#M"38````B?&)QH'!F7F"6@'.
MBTPD<(G(#ZS9&XM<)&#!X`4)R(G:`<8QR<'B'HET)&B+="1DB=")3"1LB?$/
MI-D>#ZSS`HG*P>X""=B+7"1L"?*)1"0HB=8QTHE4)"R+5"10B40D4#'"BT0D
M<(ET)%2+="0@(=`S1"0P`[0DX````(GQB<:!P9EY@EH!SHM,)&B)R`^LV1N+
M7"1PP>`%"<B)V@'&,<G!XAZ)="1@BW0D=(G0B4PD9(GQ#Z39'@^L\P+![@*)
MRHG9B?.)QHG7"<XQR0G?B70D((E,)"2+1"10B70D4(M<)&0Q\(MT)#`C1"1H
MB7PD5#-$)"@#M"3H````B?&)QH'!F7F"6@'.BTPD8(G(#ZS9&XM<)&C!X`4)
MR(G:`<8QR<'B'HET)'"+="1LB=")3"1TB?$/I-D>#ZSS`HG*P>X""=B+7"1T
M"?*)1"0PB=8QTHE4)#2+5"10B40D4#'"BT0D8(ET)%2+="0H(=`S1"0@`[0D
M\````(GQB<:!P9EY@EH!SHM,)'")R`^LV1N+7"1@P>`%"<B)V@'&,<G!XAZ)
M="1HBW0D9(G0B4PD;(GQ#Z39'@^L\P+![@*)RHG9B?.)QHG7"<XQR0G?B70D
M*(E,)"R+1"10B70D4(M<)&PQ\(MT)"`C1"1PB7PD5#-$)#`#M"3X````B?&)
MQH'!F7F"6@'.BTPD:(G(#ZS9&XM<)'#!X`4)R(G:`<8QR<'B'HET)&"+="1T
MB=")3"1DB?$/I-D>#ZSS`HG*P>X""=B+7"1D"?*)1"0@B=8QTHE$)'")5"0D
MBU0D4(ET)'2+="0P,<*+1"1H(=`S1"0H`[0D``$``(GQB<:!P9EY@EH!SHM,
M)&")R`^LV1N+7"1HP>`%"<B)V@'&,<G!XAZ)="10BW0D;(G0B4PD5(GQ#Z39
M'@^L\P+![@*)RHG9B?.)QHG7"<XQR0G?B70D,(E,)#2+1"1PB70D:(M<)%0Q
M\(MT)"@C1"1@B7PD;#-$)"`#M"0(`0``B?&)QH'!F7F"6@'.BTPD4(G(#ZS9
M&XM<)&#!X`4)R(G:`<;!XAXQ_XET)'"+="1DB=")?"1TBWPD5(GQ#Z39'@^L
M\P*)RL'N`C')"=@)\HE,)!R+3"1LB=:+5"1HBUPD)(E$)!@Q\8ET)&2+="10
M,<*)1"1@B=")RHM,)"`A\"'Z,T0D,#-4)#0#C"00`0``$YPD%`$``('!F7F"
M6H/3``'!$=.)3"1HBTPD<#'2B5PD;(M<)'2)R,'@!0^LV1N+7"1L"<B+3"1H
M`<&)\!'3B<K!X!Z)3"0HB50D:(GZ,<D/I/(>B5PD+(GSB?X/K/L"P>X"B4PD
M;(G7B=F)\XG&"<X)WXGQB?N+="1@BWPD9(E<)%0QSC'?BUPD,(E,)%")\(GZ
M(T0D<"-4)'0S1"08,U0D'`.<)!@!``"+="0TB=D3M"0<`0``B?.!P9EY@EJ#
MTP")S@'&B=\1UXET)&"+="1H,=*)?"1DBWPD;(GPB?.+="1D#ZS[&\'@!0G8
MBUPD8`'#$=8QR8E<)"")3"1DBTPD<(ET)"2)7"1@B<Z+7"1TP>8>B?")WXG.
M#Z3/'@^LW@*)^HGQB=^)Q@G.P>\"B?N)UXGRBW0D4(M,)"@)WXM$)!@QVS'6
MB50D,(M4)!PQ\0.$)"`!``")?"0TB=^)SHM,)&"+7"1D$Y0D)`$```6AZ]EN
M@](``<:)R!'7#ZS9&S'2BUPD;,'@!0G(`<81US')B=J)="1PB4PD=(M,)&B)
M="08B[0D+`$```^DRAZ)R`^LV0*)?"0<P>L"P>`>"=J+G"0H`0``"<B)1"0H
MBT0D(('#H>O9;HE4)"R#U@")V3'_B?.+="10`?&+="0P$?LS="0H,=(Q\`'!
M$=.)3"1HBTPD<#'2B5PD;(M<)'2)R(G>B<O!X`6+3"1H#ZSS&PG8BUPD;`'!
M$=.)3"0@B<HQR8E<)"2+7"1DB4PD;(M,)&")5"1HB=J+M"0T`0``#Z3*'HG(
M#ZS9`L'K`L'@'@G:BYPD,`$```G(B40D4(M$)!B!PZ'KV6Z)5"14@]8`B=DQ
M_XGSBW0D,`'QBW0D*!'[,W0D4#'2,?")WHG+BTPD:`'#$=:)R#'2B?>)WHM<
M)&S!X`4/K-D;BUPD=`G(BTPD<`'&$=<QTHG(B70D8(E4)&2)VL'@'@^DRAZ)
M="08#ZS9`HG&P>L"B7PD'(G7"<X)WXN<)#@!``"+1"0@B70D,(NT)#P!``")
M?"0T@<.AZ]EN@]8`B=DQ_XGSBW0D*`'QBW0D4!'[,W0D,#'2,?`!P1'3B4PD
M<(M,)&`QTHE<)'2+7"1DB<B)WHG+P>`%BTPD<`^L\QN+M"1$`0``"=B+7"1T
M`<$1TXE,)"")RC')B5PD)(M<)&R)3"1TBTPD:(E4)'")V@^DRAZ)R`^LV0+!
MZP+!X!X)VHN<)$`!```)R(E$)"B+1"08@<.AZ]ENB50D+(/6`(G9,?^)\XMT
M)%`!\8MT)#`1^S-T)"@QTC'PB=Z)RXM,)'`!PQ'6B<@QTHGWB=Z+7"1TP>`%
M#ZS9&XM<)&0)R(M,)&`!QA'7,=*)R(ET)!B)5"1LB=K!X!X/I,H>B7PD'`^L
MV0*)="1HP>L"B<:)UPG."=^+G"1(`0``BT0D((ET)%"+M"1,`0``@<.AZ]EN
MB7PD5(/6`(G9,?^)\XMT)#`!\8MT)"@1^S-T)%`QTC'P`<$1TXE,)&"+3"1H
M,=*)7"1DBUPD;(G(B=Z)R\'@!8M,)&`/K/,;B[0D5`$```G8BUPD9`'!$=.)
M3"0@B<HQR8E<)"2+7"1TB4PD9(M,)'")5"1@B=H/I,H>B<@/K-D"P>L"P>`>
M"=J+G"10`0``"<B)1"0PBT0D&('#H>O9;HE4)#2#U@")V3'_B?.+="0H`?&+
M="10$?LS="0P,=(Q\(G>B<N+3"1@`<,1UHG(,=*)]XG>BUPD9,'@!0^LV1N+
M7"1L"<B+3"1H`<81US'2B<B)="08B50D=(G:P>`>#Z3*'HE\)!P/K-D"B70D
M<,'K`HG&B=<)S@G?BYPD6`$``(ET)"B+M"1<`0``@<.AZ]ENB7PD+(/6`(G9
M,?^)\XMT)%`!\8MT)#"+1"0@$?LS="0H,=(Q\`'!$=.)3"1HBTPD<#'2B5PD
M;(M<)'2)R(G>B<O!X`6+3"1H#ZSS&XNT)&0!```)V(M<)&P!P1'3B4PD((G*
M,<F)7"0DBUPD9(E,)&R+3"1@B50D:(G:#Z3*'HG(#ZS9`L'K`L'@'@G:BYPD
M8`$```G(B40D4(M$)!B!PZ'KV6Z)5"14@]8`B=DQ_XGSBW0D,`'QBW0D*!'[
M,W0D4#'2,?")WHG+BTPD:`'#$=:)R#'2B?>)WHM<)&S!X`4/K-D;BUPD=`G(
MBTPD<`'&$=<QTHG(B70D&(E4)&2)VL'@'@^DRAZ)?"0<#ZS9`HET)&#!ZP*)
MQHG7"<X)WXET)#")?"0TBYPD:`$``(NT)&P!``"+1"0@@<.AZ]EN@]8`B=DQ
M_XGSBW0D*`'QBW0D4!'[,W0D,#'2,?`!P1'3B4PD<(M,)&`QTHE<)'2+7"1D
MB<B)WHG+P>`%BTPD<`^L\QN+M"1T`0``"=B+7"1T`<$1TXE,)"")RC')B5PD
M)(M<)&R)3"1TBTPD:(E4)'")V@^DRAZ)R`^LV0+!ZP+!X!X)VHN<)'`!```)
MR(E$)"B+1"08@<.AZ]ENB50D+(/6`(G9,?^)\XMT)%`!\8MT)#`1^S-T)"@Q
MTC'PB=Z)RXM,)'`!PQ'6B<@QTHGWB=Z+7"1TP>`%#ZS9&PG(`<81US'2B70D
M&(E\)!R)="1HB50D;(M,)&"+7"1DB<B)VL'@'@^DRAZ)Q@^LV0*+1"0@P>L"
MB=<)S@G?BYPD>`$``(ET)%"+M"1\`0``B7PD5('#H>O9;H/6`(G9,?^)\XMT
M)#`!\8MT)"@1^S-T)%`QTC'P`<$1TXE,)&"+3"1H,=*)7"1DBUPD;(G(B=Z)
MR\'@!8M,)&`/K/,;B[0DA`$```G8BUPD9`'!$=.)3"0@B<HQR8E<)"2+7"1T
MB4PD9(M,)'")5"1@B=H/I,H>B<@/K-D"P>L"P>`>"=J+G"2``0``"<B)1"0P
MBT0D&('#H>O9;HE4)#2#U@")V3'_B?.+="0H`?&+="10$?LS="0P,=(Q\(G>
MB<N+3"1@`<,1UHG(,=*)]XG>BUPD9,'@!0^LV1L)R`'&B70D&(M,)&@1US'2
MBUPD;(E4)'2)R(ET)'")VL'@'HE\)!P/I,H>B<8/K-D"BT0D(,'K`HG7"<X)
MWXN<)(@!``")="0HB[0DC`$``(E\)"R!PZ'KV6Z#U@")V3'_B?.+="10`?&+
M="0P$?LS="0H,=(Q\`'!$=.)3"1HBTPD<#'2B5PD;(M<)'2)R(G>B<O!X`6+
M3"1H#ZSS&XNT))0!```)V(M<)&P!P1'3B4PD((G*,<F)7"0DBUPD9(E,)&R+
M3"1@B50D:(G:#Z3*'HG(#ZS9`L'K`L'@'@G:BYPDD`$```G(B40D4('#H>O9
M;HE4)%2#U@")V3'_B?.+="0P`?&+="0H$?LS="10BT0D&#'2,?")WHG+BTPD
M:`'#$=:)R#'2B?>)WHM<)&S!X`4/K-D;BUPD=`G(BTPD<`'&$=<QTHG(B70D
M8(E4)&2)VL'@'@^DRAZ)="08#ZS9`HG&P>L"B7PD'(G7"<X)WXN<))@!``"+
M1"0@B70D,(NT))P!``")?"0T@<.AZ]EN@]8`B=DQ_XGSBW0D*`'QBW0D4!'[
M,W0D,#'2,?`!P1'3B4PD<(M,)&`QTHE<)'2+7"1DB<B)WHG+P>`%BTPD<`^L
M\QL)V(M<)'0!P1'3B4PD$(G*,<F)7"04BUPD;(E,)'2+3"1HB50D<(G:B<@/
MI,H>P>`>#ZS9`L'K`@G("=J+G"2@`0``B40D*(E4)"R+M"2D`0``@<.AZ]EN
MBT0D&(/6`(G9,?^)\XMT)%`!\8MT)#`1^S-T)"@QTC'PB=Z)RXM,)'`!PQ'6
MB<@QTHGWB=Z+7"1TP>`%#ZS9&XM<)&0)R(M,)&`!QA'7,=*)R(ET)&B)5"1L
MB=K!X!X/I,H>B70D&`^LV0*)QL'K`HE\)!R)UPG."=^+G"2H`0``BT0D$(ET
M)""+M"2L`0``B7PD)('#H>O9;H/6`(G9,?^)\XMT)#`!\8MT)"@1^S-T)"`Q
MTHM\)&PQ\(MT)&@!P1'3B?")3"1@BTPD8(E<)&2)\\'@!3'2#ZS[&PG8BUPD
M9`'!$=.)3"00B<HQR8E4)%")3"14BTPD<(E<)!2+7"1TB<B+="0@BWPD;(G:
MP>`>#Z3*'@^LV0()R(N,)+`!``#!ZP*)1"0PBT0D*`G:@<&AZ]ENBUPD5(E4
M)#0!P8M$)!@S="0PBY0DN`$``#'PB<Z+3"10`<:)R`^LV1O!X`4)R`'&BT0D
M((GS,?:)="1TBW0D:(E<)'")^XGQ#Z3S'L'A'@^L_@()SC')P>\"B4PD'(N,
M)+P!```)WX'"H>O9;HET)&"#T0")="08B<N)T3'2B7PD9`'!BT0D,!'3,=(Q
M\#-$)!`!P8E,)&B+3"1P$=.)7"1LBUPD=(G(B<K!X`4/K-H;B<8)UHGP`T0D
M:#')B40D:(M$)%")3"1LBU0D5(G!BW0D8(M\)'2)T\'A'@^DPQX/K-`"P>H"
M"<$)TR'.B<@+1"1@B=HC1"1PB4PD(#';B50D)(N4),`!```)QHE,)"B+3"0P
M@<+<O!N/B5PD+(M<)&R)T(M4)"`!R(M,)&@!QHG(#ZS9&\'@!0G(`<:)\S'V
MB70D9(MT)'")7"1@B?N)\0^D\Q[!X1X/K/X""<XQR<'O`HE,)!2+3"0D"=\)
M\HM<)"R)T"-$)&B)="10"?F)?"14B<J+3"0H(?LC5"1L"=J+7"0<B70D$"'Q
M"<B+3"08`XPDR`$``!.<),P!``"!P=R\&X^#TP`!P1'3B4PD<(E<)'2+3"1@
MBUPD9(M\)&2)R(G*P>`%#ZS:&XG&"=:+5"1LB?`#1"1P,<F+="10B40D<(M$
M)&B)TXE,)'2)P0^DPQ[!X1X/K-`""<'!Z@*)R(E,)"`+3"10"=,AQB-,)&`Q
MTHE$)#`)\8M$)"@#A"30`0``B5PD)(G.BTPD<(M<)'0%W+P;CP'&B50D-(G(
M#ZS9&\'@!0G(B?D!QHGS,?:)="1LBW0D8(E<)&B+7"0D#Z3Q'HGR#ZS^`L'O
M`L'B'@G/,<D)UHE,)!R+3"0@"?N)="10B=HC5"1T"?&)?"14B70D&(G((T0D
M<(M,)#"+7"0T(?$A^PG("=J+3"00`XPDV`$``(M<)!03G"3<`0``@<'<O!N/
M@],``<&)3"1@BTPD:!'3B5PD9(M<)&R)R(G*P>`%#ZS:&XG&"=:+5"1TB?`#
M1"1@,<F+="10B40D8(M$)'")TXE,)&2)P0^DPQ[!X1X/K-`""<'!Z@*)R(E,
M)"`+3"10"=,AQB-,)&@QTHE$)"@)\8M$)#`#A"3@`0``B5PD)(G.BTPD8(M<
M)&0%W+P;CP'&B50D+(G(#ZS9&\'@!0G(`<:)\S'VB5PD<(ET)'2+="1HBWPD
M;(M<)"2)\HGYP>(>#Z3Q'@^L_@+![P()U@G/,<F)="10B4PD%(M,)"`)^XG:
MBUPD+"-4)&2)="00"?&)?"14B<B+3"0H(?LC1"1@"=J+7"0<(?$)R(M,)!@#
MC"3H`0``$YPD[`$``('!W+P;CX/3``'!B4PD:(M,)'`1TXE<)&R+7"1TB<B)
MRL'@!0^LVAN)Q@G6BU0D9(GP`T0D:#')BW0D4(E$)&B+1"1@B=.)3"1LB<$/
MI,,>P>$>#ZS0`@G!P>H"B<B)3"0@"TPD4`G3(<8C3"1P,=*)7"0D"?&)1"0P
MB<Z)5"0TBTPD:(M$)"@#A"3P`0``BUPD;`7<O!N/BWPD=`'&B<C!X`4/K-D;
M"<B)^0'&B?,Q]HET)&2+="1PB5PD8(M<)"0/I/$>B?(/K/X"P>\"P>(>"<\Q
MR0G6B4PD'(M,)"`)^XG:BUPD-"-4)&R)="10"?&)="08B<B+3"0P(?LC1"1H
M"=J+7"04B7PD5"'Q"<B+3"00`XPD^`$``!.<)/P!``"!P=R\&X^#TP`!P8E,
M)'"+3"1@$=.)7"1TBUPD9(G(B<K!X`4/K-H;B<8)UHGP`T0D<#')B4PD=(E$
M)'"+1"1HBU0D;(MT)%")P8M\)&2)T\'A'@^DPQX/K-`""<'!Z@*)R(E,)"`+
M3"10"=,AQB-,)&")1"0H,=()\8M$)#`#A"0``@``B5PD)(G.BTPD<(M<)'0%
MW+P;CP'&B50D+(G(#ZS9&\'@!0G(B?D!QHGS,?:)="1LBW0D8(E<)&B+7"0D
M#Z3Q'HGR#ZS^`L'O`L'B'@G/,<D)UHE,)!2+3"0@"?N)VHM<)"PC5"1TB70D
M4`GQB7PD5(G(BTPD*"'[(T0D<`G:B70D$(M<)!PA\0G(BTPD&`.,)`@"```3
MG"0,`@``@<'<O!N/BWPD;(/3``'!B4PD8(M,)&@1TXE<)&2+7"1LB<B)RL'@
M!0^LVAN)Q@G6BU0D=(GP`T0D8#')BW0D4(E$)&"+1"1PB=.)3"1DB<$/I,,>
MP>$>#ZS0`@G!P>H"B<B)3"0@"TPD4`G3(<8C3"1H,=*)1"0P"?&+1"0H`X0D
M$`(``(E<)"2)SHM,)&"+7"1D!=R\&X\!QHE4)#2)R`^LV1O!X`4)R(GY`<:)
M\S'VB70D=(MT)&B)7"1PB?(/I/$>P>(>#ZS^`L'O`@G6"<\QR8ET)%")?"14
MB70D&(E,)!R+3"0@BUPD)`GQ"?N)R(M,)#`C1"1@B=J+7"0T(U0D9"'Q(?L)
MR(M,)!`)V@.,)!@"``"+7"04$YPD'`(``('!W+P;CX/3``'!B4PD:(M,)'`1
MTXE<)&R+7"1TB<B)RL'@!0^LVAN)Q@G6BU0D9(GP`T0D:#')BW0D4(E$)&B+
M1"1@B=.)3"1LB<$/I,,>P>$>#ZS0`@G!P>H"B<B)3"0@"TPD4`G3(<8C3"1P
M,=*)1"0H"?&+1"0P`X0D(`(``(E<)"2)SHM,)&B+7"1L!=R\&X\!QHE4)"R)
MR`^LV1O!X`4)R`'&B?,Q]HE<)&"+?"1TB70D9(MT)'")^8M<)"0/I/$>B?(/
MK/X"P>\"P>(>"<\QR0G6B4PD%(M,)"`)^XG:BUPD+"-4)&R)="10"?&)="00
MB<B+3"0H(?LC1"1H"=J+7"0<B7PD5"'Q"<B+3"08`XPD*`(``!.<)"P"``"!
MP=R\&X^#TP`!P8E,)'"+3"1@$=.)7"1TBUPD9(G(B<K!X`4/K-H;B<8)UHM4
M)&R)\`-$)'`QR8E$)'"+1"1HB=.)3"1TB<$/I,,>P>$>#ZS0`L'J`@G!"=.)
MR(E,)"`+3"10B5PD)"-,)&`QTHMT)%"+7"1TB40D,(M\)&2)5"0T(<:+1"0H
M"?$#A"0P`@``B<Z+3"1P!=R\&X\!QHG(#ZS9&\'@!0G(B?D!QHGS,?:)="1L
MBW0D8(E<)&B+7"0D#Z3Q'HGR#ZS^`L'O`L'B'@G/,<D)UHE,)!R+3"0@"?N)
MVHM<)#0C5"1TB70D4`GQB70D&(G(BTPD,"'[(T0D<`G:BUPD%(E\)%0A\0G(
MBTPD$`.,)#@"```3G"0\`@``@<'<O!N/@],``<&)3"1@BTPD:!'3B5PD9(M<
M)&R)R(G*P>`%#ZS:&XG&"=:)\`-$)&"+5"1T,<F+="10BWPD;(E$)&"+1"1P
MB4PD9(G3B<$/I,,>P>$>#ZS0`@G!P>H"B<B)3"1P"TPD4`G3(TPD:"'&B40D
M*#'2"?&+1"0P`X0D0`(``(E<)'0%W+P;CXG+BTPD8(E4)"P!PXM4)'")WHM<
M)&2)R,'@!0^LV1L)R`'&BT0D8(GS,?:)="14BW0D:(E<)%")^XGQ#Z3S'L'A
M'@^L_@+![P()\0G[B=Z)RS')B4PD)(M,)"@)VB'0B70D;(MT)!@AV8E<)"`)
MR`.T)$@"``")7"1HB?&)QH'!W+P;CP'.BTPD4(M<)%2+5"1LB<@/K-D;P>`%
M"<@!QC'_B70D<(MT)&")?"1TBWPD9(GQB?O!X1X/I/,>#ZS^`HGPB=Z)R\'O
M`@G#BT0D:`G^,<F)]XE<)#")WHG3B4PD-(G!"?LC1"0P"?&)="1@BW0D4(E\
M)&2+?"14(U0D-"'Q(?L)P8M$)"@)TP.$)%`"``"+5"0L$Y0D5`(```7<O!N/
M@](``<$1TXE,)&B+3"1P,=*)7"1LBUPD=(G(P>`%#ZS9&XM<)&P)R(M,)&@!
MP1'3B4PD*(G*,<F)7"0LB?L/I/,>B4PD;(GQ#ZS^`L'A'L'O`HGPB=X)_HG+
MB50D:`G#B?(Q]HG8B70D%(E<)!"+7"1@BW0D9(M,)"")1"10"<.)5"14BWPD
M;`G6B=B+7"10(T0D<"-<)#")\HMT)%0C5"1T(W0D-`G8"?(#C"18`@``BUPD
M)!.<)%P"``"!P=R\&X^+="1H@],``<$1TXGPB4PD8#'2B5PD9(GSP>`%BW0D
M9`^L^QL)V(M<)&`!PXM$)'`1UHM4)'0QR8E<)"")="0DB<;!YAZ)UXE,)&0/
MI,<>B?&)QHE<)&`/K-8"B?N)U\'O`HGPB<X)QHGZBT0D4(G?"=>)="10,=(Q
M\(MT)#`S1"0HB7PD5(M\)#0#M"1@`@``B?$3O"1D`@``B<:!P=;!8LJ)^XG7
M@],``<Z+3"1@$=^+7"1D,=*)R,'@!0^LV1N+7"1L"<@!QA'7,<F)VHET)'")
M3"1TBTPD:(ET)!B)R`^DRAZ)?"0<P>`>#ZS9`HG7B<;!ZP*+1"00"<Z+3"0@
M"=\QVXGRBW0D4(E\)#2)5"0P,=:+5"04,?$#A"1H`@``$Y0D;`(```76P6+*
M@](``<$1TXE,)&B+3"1P,=*)7"1LBUPD=(G(B=Z)R\'@!8M,)&@/K/,;"=B+
M7"1L`<$1TXE,)"")RC')B50D:(E,)&R+3"1@B5PD)(M<)&2)R(NT)'0"``")
MVL'@'@^DRAX/K-D"P>L""<@)VHN<)'`"``")1"0HBT0D&(E4)"R!P];!8LJ#
MU@")V3'_B?.+="10`?&+="0P$?LS="0H,=(Q\(G>B<N+3"1H`<,1UHG(,=*)
M]XG>BUPD;,'@!0^LV1N+7"1T"<B+3"1P`<81US'2B<B)="1@B50D9(G:P>`>
M#Z3*'HET)!@/K-D"B<;!ZP*)?"0<B=<)S@G?BYPD>`(``(M$)"")="10B[0D
M?`(``(E\)%2!P];!8LJ#U@")V3'_B?.+="0P`?&+="0H$?LS="10,=(Q\`'!
M$=.)3"1PBTPD8#'2B5PD=(M<)&2)R(G>B<O!X`6+3"1P#ZSS&PG8BUPD=`'!
M$=.)3"0@B<HQR8E<)"2+7"1LB4PD=(M,)&B)5"1PB=J+M"2$`@``#Z3*'HG(
M#ZS9`L'K`L'@'@G:BYPD@`(```G(B40D,(M$)!B!P];!8LJ)5"0T@]8`B=DQ
M_XGSBW0D*`'QBW0D4!'[,W0D,#'2,?")WHG+BTPD<`'#$=:)R#'2B?>)WHM<
M)'3!X`4/K-D;BUPD9`G(BTPD8`'&$=<QTHG(B70D:(E4)&R)VL'@'@^DRAZ)
M="08#ZS9`HG&P>L"B7PD'(G7"<X)WXN<)(@"``"+1"0@B70D*(NT)(P"``")
M?"0L@</6P6+*@]8`B=DQ_XGSBW0D4`'QBW0D,!'[,W0D*#'2,?`!P1'3B4PD
M8(M,)&@QTHE<)&2+7"1LB<B)WHG+P>`%BTPD8`^L\QN+M"24`@``"=B+7"1D
M`<$1TXE,)"")RC')B5PD)(M<)'2)3"1DBTPD<(E4)&")V@^DRAZ)R`^LV0+!
MZP+!X!X)VHN<))`"```)R(E$)%"+1"08@</6P6+*B50D5(/6`(G9,?^)\XMT
M)#`!\8MT)"@1^S-T)%`QTC'PB=Z)RXM,)&`!PQ'6B<@QTHGWB=Z+7"1DP>`%
M#ZS9&XM<)&P)R(M,)&@!QA'7,=*)R(ET)!B)5"1TB=K!X!X/I,H>B7PD'`^L
MV0*)="1PP>L"B<:)UPG."=^+G"28`@``BT0D((ET)#"+M"2<`@``@</6P6+*
MB7PD-(/6`(G9,?^)\XMT)"@!\8MT)%`1^S-T)#`QTC'P`<$1TXE,)&B+3"1P
M,=*)7"1LBUPD=(G(B=Z)R\'@!8M,)&@/K/,;B[0DI`(```G8BUPD;`'!$=.)
M3"0@B<HQR8E<)"2+7"1DB4PD;(M,)&")5"1HB=H/I,H>B<@/K-D"P>L"P>`>
M"=J+G"2@`@``"<B)1"0HBT0D&('#UL%BRHE4)"R#U@")V3'_B?.+="10`?&+
M="0P$?LS="0H,=(Q\(G>B<N+3"1H`<,1UHG(,=*)]XG>BUPD;,'@!0^LV1N+
M7"1T"<B+3"1P`<81US'2B<B)="08B50D9(G:P>`>#Z3*'HE\)!P/K-D"B70D
M8,'K`HG&B=<)S@G?BYPDJ`(``(ET)%"+M"2L`@``@</6P6+*B7PD5(/6`(G9
M,?^)\XMT)#`!\8MT)"B+1"0@$?LS="10,=(Q\`'!$=.)3"1PBTPD8#'2B5PD
M=(M<)&2)R(G>B<O!X`6+3"1P#ZSS&XNT)+0"```)V(M<)'0!P1'3B4PD((G*
M,<F)7"0DBUPD;(E,)'2+3"1HB50D<(G:#Z3*'HG(#ZS9`L'K`L'@'@G:BYPD
ML`(```G(B40D,(M$)!B!P];!8LJ)5"0T@]8`B=DQ_XGSBW0D*`'QBW0D4!'[
M,W0D,#'2,?")WHG+BTPD<`'#$=:)R#'2B?>)WHM<)'3!X`4/K-D;BUPD9`G(
MBTPD8`'&$=<QTHG(B70D&(E4)&R)VL'@'@^DRAZ)?"0<#ZS9`HET)&C!ZP*)
MQHG7"<X)WXET)"B)?"0LBYPDN`(``(NT)+P"``"+1"0@@</6P6+*@]8`B=DQ
M_XGSBW0D4`'QBW0D,!'[,W0D*#'2,?`!P1'3B4PD8(M,)&@QTHE<)&2+7"1L
MB<B)WHG+P>`%BTPD8`^L\QN+M"3$`@``"=B+7"1D`<$1TXE,)"")RC')B5PD
M)(M<)'2)3"1DBTPD<(E4)&")V@^DRAZ)R`^LV0+!ZP+!X!X)VHN<),`"```)
MR(E$)%"+1"08@</6P6+*B50D5(/6`(G9,?^)\XMT)#`!\8MT)"@1^S-T)%`Q
MTC'PB=Z)RXM,)&`!PQ'6B<@QTHGWB=Z+7"1DP>`%#ZS9&PG(`<81US'2B70D
M&(E\)!R)="1PB50D=(M,)&B+7"1LB<B)VL'@'@^DRAZ)Q@^LV0*+1"0@P>L"
MB=<)S@G?BYPDR`(``(ET)#"+M"3,`@``B7PD-('#UL%BRH/6`(G9,?^)\XMT
M)"@!\8MT)%`1^S-T)#`QTC'P`<$1TXE,)&B+3"1P,=*)7"1LBUPD=(G(B=Z)
MR\'@!8M,)&@/K/,;B[0DU`(```G8BUPD;`'!$=.)3"0@B<HQR8E<)"2+7"1D
MB4PD;(M,)&")5"1HB=H/I,H>B<@/K-D"P>L"P>`>"=J+G"30`@``"<B)1"0H
MBT0D&('#UL%BRHE4)"R#U@")V3'_B?.+="10`?&+="0P$?LS="0H,=(Q\(G>
MB<N+3"1H`<,1UHG(,=*)]XG>BUPD;,'@!0^LV1L)R`'&B70D&(M,)'`1US'2
MBUPD=(E4)&2)R(ET)&")VL'@'HE\)!P/I,H>B<8/K-D"BT0D(,'K`HG7"<X)
MWXN<)-@"``")="10B[0DW`(``(E\)%2!P];!8LJ#U@")V3'_B?.+="0P`?&+
M="0H$?LS="10,=(Q\`'!$=.)3"1PBTPD8#'2B5PD=(M<)&2)R(G>B<O!X`6+
M3"1P#ZSS&XNT).0"```)V(M<)'0!P1'3B4PD((G*,<F)7"0DBUPD;(E,)'2+
M3"1HB50D<(G:#Z3*'HG(#ZS9`L'K`L'@'@G:BYPDX`(```G(B40D,('#UL%B
MRHE4)#2#U@")V3'_B?.+="0H`?&+="10$?LS="0PBT0D&#'2,?")WHG+BTPD
M<`'#$=:)R#'2B?>)WHM<)'3!X`4/K-D;BUPD9`G(BTPD8`'&$=<QTHG(B70D
M:(E4)&R)VL'@'@^DRAZ)="08#ZS9`HG&P>L"B7PD'(G7"<X)WXN<).@"``"+
M1"0@B70D*(NT).P"``")?"0L@</6P6+*@]8`B=DQ_XGSBW0D4`'QBW0D,!'[
M,W0D*#'2BWPD;#'PBW0D:`'!$=.)\(E,)&"+3"1@B5PD9(GSP>`%,=(/K/L;
M"=B+7"1D`<$1TXE,)"")RC')B5PD)(M<)'2)3"1DBTPD<(E4)&")VHG(#Z3*
M'L'@'@^LV0*)U\'K`HG&"<X)WXN,)/`"``")="10B7PD5(M$)#"!P=;!8LJ+
M="0HBUPD9`'!BT0D&#-T)%"+5"1L,?")SHM,)&`!QHG(#ZS9&\'@!0G(`<:+
M1"1H,?^)="1PB=:)PP^DQAZ)?"1TP>,>#ZS0`HG9P>H"B?,)P0G3BT0D2`.$
M)/@"``")3"1HBTPD*`76P6+*B5PD;(M<)%`!R(M,)"`S7"1HB<8QV8M<)'0!
MSHM,)'")R`^LV1N+7"1<P>`%"<@!QC'_BT0D<`-$)$"),XMT)&`QTHE[!(M\
M)&2)0PB)\,'@'@^L_@*)4PP)\`-$)'B+?"1<,=*+3"1H`TPD.(E7%#'2B4<0
MBT0D4(E7'`-$)`@QTHE/&(E'((E7)(N$)`P#``!E*P44````=0B-9?1;7E]=
MP^@!!0``D/,/'ON-3"0$@^3P_W'\58GE4^A9L?__@<,-:@``48/L#&I\Z'BM
M__]F#V^#G.'__X/$$,=`,``````/$0!F#V^#K.'__\=`-``````/$4`09@]O
M@[SA___'0'@`````#Q%`((UE^%E;78UA_,.-=@#S#Q[[Z#30__\%JVD``(U,
M)`2#Y/#_<?Q5B>575E-1@^PHB47,BT$$BQ&)1>"+00B)PXG&B47DP>,#P?X?
MB470B=D#2B@Q_XEUU#M**(MR,(E]W(MZ-(M%W(E-V!M"+',&@\8!@]<`BTW8
MBUW<BT)XB4HHBTW0B5HLBUW4#ZS9'<'K'0'QC7(X$?N)2C")6C2%P`^%&`$`
M`(M-Y(/Y/P^.?P```(G+C4'`BWW@B57DP>L&B470B?*-2__!XP:)_HE-V`'[
MB=<NC;0F`````&:0\P]O!HM%Y(/&0`\1!_,/;T;0#Q%'$/,/;T;@#Q%'(/,/
M;T;P#Q%',.A3S___.=YUSXM%T(M-V(G^BUW@BU7DB<?!X0:#X,`ISXU$`T")
M?>2)1>"+?>2#_P1R78M=X(L#B=F)0CB+?>2+1#O\B40^_(U"/(/@_"G&*?$!
M_H/F_(/^!'(<B57D@^;\,=N+%!F)%!B#PP0Y\W+SBU7DB7WDD(M%Y(E">(UE
M\%E;7E]=C6'\PXVV`````(7_=.2+1>"#YP(/M@"(0CATUHM%X(M=Y`^W1!C^
M9HE$'O[KQ(UT)@")5="Y0````(M5Y"G!.=$/3\J#[`0!\%&)3=C_=>!0BUW,
MZ-FJ__^+5="+3=B#Q!")R`-">(E">(/X0'6)B=")5=@I3>0!3>#H4\[__XM5
MV.F3_O__+HVT)@````"-=@#S#Q[[Z"3.__\%FV<``(U,)`2#Y/#_<?Q5B>57
M5E-1@^P8BUD$BS&)1>2+0RB+4RR->S@/R(E%X(M#,`_(B47<BT,H#ZS0`X/@
M/XU0`<9$`SB`C007@_HX#XXJ`0``N4`````IT70;,=+VP0$/A:X!``#&!!``
MQD00`0"#P@(YRG+PB=CHM\W__V8/[\`/$4,X#Q%'(`\11Q`/$4<HBT7<B4-P
MBT7@B4-TB=CHD,W__XM3!(L#@^P,#ZS0&(@&BU,$BP,/K-`0B$8!BP.(9@*+
M`XA&`XM3#(M#"`^LT!B(1@2+4PR+0P@/K-`0B$8%BT,(B&8&BT,(B$8'BU,4
MBT,0#ZS0&(A&"(M3%(M#$`^LT!"(1@F+0Q"(9@J+0Q"(1@N+4QR+0Q@/K-`8
MB$8,BU,<BT,8#ZS0$(A&#8M#&(AF#HM#&(A&#XM3)(M#(`^LT!B(1A"+0R"+
M4R0/K-`0B$81BT,@B&82BT,@B$834XM=Y.B;J/__@\00C67P65M>7UV-8?S#
MC70F`+DX````*=&#^01R;(U0!,<``````(/B_,=$"/P`````*=`!R(/@_(/X
M!`^"Y?[__XG'C4C_@^?\P>D"B7W8OP0```"#X0''`@`````YQP^#P?[__X7)
M=5C'!#H`````QT0Z!`````"+1=B#QP@YQW+GZ9_^__]FD(7)#X25_O__Q@``
M]L$"#X2)_O__,=)FB50(_NE]_O__N@$```#&```YR@^"0O[__^E-_O__C78`
MQT($`````(M%V+\(````.<=RE>E-_O__4^B:K/__@<-.90``@^P(_[,@`0``
M_W0D'/]T)!S_="0<Z!JG__^#Q!A;PV:09I"04^AJK/__@<,>90``@^P(Z*RH
M__]3@^P(Z%.L__^!PP=E``"#Q`A;PP``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````,````!``(`)7,O)7,`+W!R;V,O<V5L9B]E>&4`1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C
M+R5I+R5S`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!0
M15),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!
M3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"
M04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`#$`;'-E96L@9F%I;&5D`')E860@
M9F%I;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M<`!414U01$E2`%1-
M4`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P!P87)L`"YP87(`
M<VAO<G0@<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T
M96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`,2XP
M-C,`+64`+2T`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?
M<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)
M3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE
M7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U
M8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*
M;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE
M.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S
M:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E
M860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#
M*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@
M,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4[
M"GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M
M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG
M(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T
M:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I
M.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE
M("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,
M051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L
M"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP
M(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F
M:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M
M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS
M>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E
M<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'
M24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!
M1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@
M*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG
M="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@
M)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]
M"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M
M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I
M;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-
M04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA
M9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E
M=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F
M+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F
M("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F
M;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D
M8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F
M9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I
M>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F
M<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@
M,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q
M=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*
M;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D
M8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D
M,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D
M9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@
M/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD
M<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D
M:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E
M('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D
M:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN
M<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE
M(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO
M9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR
M97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@
M:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N
M86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M
M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@
M>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O
M;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M
M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@
M>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I
M("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R
M7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE
M*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O
M<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN
M960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@
M<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*
M<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R
M(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D17
M4B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;
M0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I
M.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@
M=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE
M9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H
M(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ
M*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*
M:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY
M("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA
M;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B
M)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D[
M"FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M
M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E
M9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F
M:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D
M9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?
M<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92![
M"FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T
M.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H
M)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X
M9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C
M86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R
M:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO
M9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D
M<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&
M:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E
M.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D
M(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N
M86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D[
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@
M870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M
M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE
M;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M
M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I
M9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE
M(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%
M3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA
M;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*
M;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E
M861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ
M<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN
M+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X
M=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P
M-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N
M;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB
M('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I
M<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD
M,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!2
M3T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U
M8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z
M.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE
M.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I
M<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE
M<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO
M861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER
M92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR
M97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER
M92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L
M93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T
M:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[
M4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@
M>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O
M<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M
M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(
M12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA
M9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%
M(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A
M8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@
M(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I
M<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@
M/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D
M:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@
M>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL
M;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M
M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH
M;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D
M8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET
M:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR
M971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE
M?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%
M3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD
M("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E
M;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*
M)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN
M9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[
M7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E
M;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,
M3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*
M:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````_____P````#_____
M``````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M``````````$;`SL8`0``(@```'!?__]@`0``\&+__X0!```08___+`H``%!E
M__\T`0``D&;__Y@!``!@9____`$``/!G__](`@``@&G__P@#``#@:___B`,`
M`+!L__\8!```$&W__V@$``!0;?__E`0``#!N__\L!0``0&[__T`%``"`</__
M0`8``,!P__]P!@``\''__^@&```P=O__*`<``*!V__]$!P``X';__VP'``!P
M>/__'`@``*!X__]("```<'G__Z@(``#P@?__\`@``/"#___`"0``O83__W0*
M``#!A/__B`H``,6$__^<"@``T(3__[`*```0M/__Y`H``("T__\<"P``D+;_
M_V0+``#@N/__K`L``!"Y___8"P``%``````````!>E(``7P(`1L,!`2(`0<(
M$````!P````49/__+``````````4``````````%Z4@`!?`@!&PP$!(@!```@
M````'`````A>__^``P````X(1@X,2@\+=`1X`#\:.RHR)"(0````0````&1A
M__\(`````````&````!4````\&3__\<`````00X(A0)##@R'`T$.$(8$00X4
M@P5.#C!_#C1!#CA$#CQ!#D!(#C!9"@X40\,.$$'&#@Q!QPX(0<4.!$@+=`H.
M%$/##A!!Q@X,0<<."$'%#@1!"P!(````N````%QE__^"`````$$."(8"00X,
M@P-.#H@!4@Z,`4$.D`%(#H`!80Z(`4(.C`%!#I`!2`Z``6,*#@Q!PPX(0<8.
M!$$+````O`````0!``"@9?__C@$```!!#@B%`D$.#(<#00X0A@1!#A2#!5$.
MH`%M"@X40<,.$$'&#@Q!QPX(0<4.!$H+0PZL`4$.L`%(#J`!20ZL`4$.L`%(
M#J`!<PZL`4$.L`%J#JP!1PZH`44.K`%!#K`!00ZT`44.N`%"#KP!00[``4@.
MJ`%%#JP!00ZP`4@.H`%8#JP!00ZP`4@.H`%##JP!00ZP`4@.H`%##JP!00ZP
M`4@.H`%2#JP!00ZP`5`.H`$`?````,0!``!P9O__4P(```!!#@B%`D4.#(<#
M00X0A@1!#A2#!4X.7%8.8$@.4%H.7$,.8$P.4`)0#EQ+#F!(#E`"<PH.%$'#
M#A!!Q@X,0<<."$'%#@1)"P)H#EQ$#F!2#E!9#E1!#EA%#EQ!#F!4#E!9#EA$
M#EQ!#F!.#E````",````1`(``%!H___&`````$$."(4"00X,AP-!#A"&!$$.
M%(,%1@Z4($<.Q"!@#L@@30[,($$.T"!(#L`@70[$($$.R"!!#LP@0P[0($@.
MP"!6"@X40<,.$$'&#@Q!QPX(0<4.!$$+1P[$($$.R"!&#LP@00[0($@.P"!/
M#L0@00[(($$.S"!##M`@2`[`(`!,````U`(``)!H__]>`````$4."(8"00X,
M@P-.#A!-#A1,#AA!#AQ##B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ##C!(#@Q!
MPPX(0<8.!````"@````D`P``H&C__SH`````10X(@P).#A!'#A1,#AA!#AQ)
M#B!(#@A!PPX$E````%`#``"T:/__T@````!%#@B%`D$.#(<#00X0A@1!#A2#
M!48.E"!*#I1`1P[`0&0.R$!'#LQ`00[00$<.U$!%#MA`0@[<0$4.X$!(#L1`
M10[(0$@.S$!!#M!`2`[`0$<.S$!&#M!`3`[`0$L.Q$!!#LA`00[,0$$.T$!-
M#L!`5@H.%$/##A!!Q@X,0<<."$'%#@1!"P`0````Z`,``/QH__\)````````
M`/P```#\`P``^&C__S4"````10X(A0)!#@R'`T$.$(8$00X4@P5&#I0@2@ZP
M(7\.N"%"#KPA0P[`(4@.L"%M"@X40<,.$$'&#@Q!QPX(0<4.!$L+0PZ\(4$.
MP"%&#KPA00ZX(4L.O"%!#L`A2`ZP(7@.N"%!#KPA00[`(4@.L"%+#KPA00[`
M(4@.L"%M#KPA00[`(4@.L"%)#KPA00[`(4P.L"%2#K0A00ZX(40.O"%!#L`A
M1`[$(44.R"%"#LPA2`[0(4@.N"%$#KPA00[`(4@.L"%7#K@A1`Z\(4(.P"%(
M#K`A?0ZX(4(.O"%!#L`A2`ZP(50.O"%!#L`A2`ZP(0`L````_`0``#AJ__\V
M`````$4."(8"00X,@P-.#AA&#AQ!#B!8#@Q!PPX(0<8.!`!T````+`4``$AJ
M__\D`0```$4."(4"00X,AP-!#A"&!$$.%(,%1@Z4($<.L"!T#KP@00[`($@.
ML"`"0`ZX($(.O"!!#L`@2`ZP($X.O"!!#L`@2`ZP(%8*#A1!PPX00<8.#$''
M#@A!Q0X$0@M##KP@1P[`($@.L"`\````I`4```!K__\T!````$4."(4"00X,
MAP-!#A"&!$P.%(,%0PY``^P#"@X41\,.$$'&#@Q!QPX(0<4.!$4+&````.0%
M````;___:0````!1#B`"1`H.!$L+`"0`````!@``5&___S<`````10X(@P).
M#A!%#A1$#AA(#AQ"#B````"L````*`8``&QO__^$`0```$$."(4"00X,AP-!
M#A"&!$$.%(,%1PP#E(`$3@T$0P[`@`1=#L2`!$(.R(`$0@[,@`1!#M"`!`)"
M#L"`!%(.Q(`$1`[(@`1$#LR`!$$.T(`$2`[`@`1.#L2`!$4.R(`$00[,@`1!
M#M"`!$@.P(`$`F@*#A1!PPX00<8.#$''#@A!Q0X$1`MT"@[,@`1'#M"`!$4+
M0PH.S(`$1P[0@`1%"R@```#8!@``3'#__R\`````10X(@P).#A!(#AQ!#B!(
M#A!)#@A!PPX$````7`````0'``!0</__R`````!%#@B%`D$.#(<#00X0A@1!
M#A2#!4X.0'T*#A1#PPX00<8.#$''#@A!Q0X$1PM##DQ!#E!H#D1)#DA!#DQ'
M#E!!#E1%#EA"#EQ!#F!,#D``1````&0'``#`</__@`@```!(#`$`21`%`G4`
M01`'`G5\3@\#=7`&$`8"=7@0`P)U=`-*`PK!#`$`0<-!QD''0<5##`0$1PL`
MS````*P'``#X>/__]P$```!%#@B%`D$.#(<#00X0A@1!#A2#!4X.,`))#C1"
M#CA!#CQ!#D!(#C!)#C1'#CA%#CQ##D!+#C!4#C1"#CA!#CQ##D!(#C!C#C1!
M#CA!#CQ##D!(#C!##C1(#CA!#CQ##D!(#C1'#CA!#CQ##D!<#C!/#CA%#CQ!
M#D!(#C!E"@X40<,.$$'&#@Q!QPX(0<4.!$0+0PH./$8.0$@.,$\./$<.0$D+
M<PXX00X\0PY`2`XP1@H.-$<..$(./$<.0$4+`&@```!\"```*'K__\T`````
M10X(AP)!#@R&`T$.$(,$3@X@`DT*#A!!PPX,0<8."$''#@1+"T,.+$$.,$@.
M+$$.*$(.+$$.,%@.)$@.*$$.+$$.,$@.(%0*#A!#PPX,0<8."$''#@1%"P``
M`$0```#H"```W%C__SP"````2`P!`$D0!0)U`$$0!P)U?$00!@)U>!`#`G5T
M3`\#=7`&`V,!"L$,`0!!PT'&0<=!Q4,,!`1!"Q`````P"0``07K__P0`````
M````$````$0)```Q>O__!``````````0````6`D``"%Z__\$`````````#``
M``!L"0``&'K__S\O````00X(A0)"#05!AP-6A@2#!0,<+PK#0<9!QT'%#`0$
M00L````T````H`D``"2I__]M`````$@,`0!)$`4"=0!!$`,"=7Q,#P-U>`8"
M2<$,`0!!PT'%0PP$!````$0```#8"0``7*G__P4"````4@P!`$D0!0)U`$0/
M`W5P!A`'`G5\$`8"=7@0`P)U=`-;`0K!#`$`0<-!QD''0<5##`0$1PL``$0`
M```@"@``)*O__U`"````4@P!`$D0!0)U`$0/`W5P!A`'`G5\$`8"=7@0`P)U
M=`-=`0K!#`$`0<-!QD''0<5##`0$10L``"@```!H"@``+*W__RL`````00X(
M@P).#A!&#A1$#AA$#AQ$#B!(#@A!PPX$&````)0*```PK?__%`````!!#@B#
M`DX.$```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````"`7``#0%@```0````\#```!````'P,```P`````$```#0```-1I```9
M````W,T``!L````$````&@```.#-```<````!````/7^_V\T`@``!0```+0&
M```&````5`(```H```"+`P``"P```!`````5``````````,```#DS@```@``
M`+@!```4````$0```!<```#T"P``$0```&P+```2````B````!,````(````
M'@````@```#[__]O`0``"/[__V_,"@``____;P$```#P__]O0`H``/K__V\%
M`````````````````````````````````````````````````````````.3-
M`````````````#80``!&$```5A```&80``!V$```AA```)80``"F$```MA``
M`,80``#6$```YA```/80```&$0``%A$``"81```V$0``1A$``%81``!F$0``
M=A$``(81``"6$0``IA$``+81``#&$0``UA$``.81``#V$0``!A(``!82```F
M$@``-A(``$82``!6$@``9A(``'82``"&$@``EA(``*82``"V$@``QA(``-82
M``#F$@``]A(```83```6$P``)A,``#83``!&$P``5A,``&83``!V$P``AA,`
M`)83````````````````````````````````````````````````````````
M``````````#`$P````````30```*4$%2+G!M"@````#L<@``1T-#.B`H36%G
M96EA(#$T+C$N,"TP+E)#+C(N;6=A,3`I(#$T+C$N,"`R,#(T,#4P,R`H<')E
M<F5L96%S92D`1T-#.B`H36%G96EA(#$T+C(N,"TQ+FUG83$P*2`Q-"XR+C``
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92YG
M;G4N<')O<&5R='D`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N
M9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N
M<F5L+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE
M:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y
M`"YD>6YA;6EC`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````
M````````````````````````````````````"P````$````"````M`$``+0!
M```3```````````````!`````````!,````'`````@```,@!``#(`0``)```
M````````````!``````````F````!P````(```#L`0``[`$``"@`````````
M``````0`````````.0````<````"````%`(``!0"```@```````````````$
M`````````$<```#V__]O`@```#0"```T`@``(`````8`````````!`````0`
M``!1````"P````(```!4`@``5`(``&`$```'`````0````0````0````60``
M``,````"````M`8``+0&``"+`P`````````````!`````````&$```#___]O
M`@```$`*``!`"@``C`````8``````````@````(```!N````_O__;P(```#,
M"@``S`H``*`````'`````0````0`````````?0````D````"````;`L``&P+
M``"(````!@`````````$````"````(8````)````0@```/0+``#T"P``N`$`
M``8````7````!`````@```"/`````0````8`````$````!```"``````````
M``````0`````````B@````$````&````(!```"`0``"``P`````````````0
M````!````)4````!````!@```*`3``"@$P``"```````````````"`````@`
M``">`````0````8```#`$P``P!,``!16`````````````"``````````I```
M``$````&````U&D``-1I```4```````````````$`````````*H````!````
M`@````!P````<```L$``````````````$`````````"R`````0````(```"P
ML```L+```!P!``````````````0`````````P`````$````"````S+$``,RQ
M``#<"@`````````````$`````````,H````.`````P```-S-``#<O0``!```
M````````````!`````0```#6````#P````,```#@S0``X+T```0`````````
M``````0````$````X@````8````#````Y,T``.2]`````0``!P`````````$
M````"````)D````!`````P```.3.``#DO@``'`$`````````````!`````0`
M``#K`````0````,`````T````,```!@```````````````0`````````\0``
M``@````#````&-```!C````4```````````````$`````````/8````!````
M,``````````8P```8P```````````````0````$````!`````P``````````
;````>\```/\```````````````$`````````
